#!/usr/bin/env python
import os
import sys
import json
from argparse import ArgumentParser

from jinja2 import Template, Environment, FileSystemLoader


def parseVar(value):
    (name, replacement) = value.split('=')
    if replacement.startswith('@'):
        with open(replacement[1:].strip(), 'r') as ifh:
            replacement = ifh.read()
    if replacement.startswith(':'):
        with open(replacement[1:].strip(), 'r') as ifh:
            replacement = json.load(ifh)
    return name, replacement


if __name__ == '__main__':
    parser = ArgumentParser(description='generate static html site with replacements')
    parser.add_argument('--di', '-i', type=str, default='html-in', help='html template directory')
    parser.add_argument('--do', '-o', type=str, default='html-out',  help='output directory')
    parser.add_argument('--var', '-v', nargs='*', help='variable to replace')
    args = parser.parse_args()

    if not os.path.exists(args.do): os.makedirs(args.do)

    variables = dict()
    if args.var:
        for var in args.var:
            n, r = parseVar(var)
            variables[n] = r

    filenames = list()
    for root, dirs, files in os.walk(args.di):
        for f in files:
            if not f.endswith('~') and not os.path.basename(f).startswith('__'):
                fi = os.path.join(root, f)
                fo = fi.replace(args.di, args.do, 1)
                filenames.append((fi, fo))

    env = Environment(loader=FileSystemLoader(args.di))
    for infile, outfile in filenames:
        if not os.path.exists(os.path.dirname(outfile)):
            os.makedirs(os.path.dirname(outfile))
        with open(outfile, 'w') as ofh:
            with open(infile, 'r') as ifh:
                t = env.from_string(ifh.read())
                o = t.render(**variables)
                ofh.write(o)
